@@ -1,27 +1,28 @@
-import logging
+from logging import getLogger
 from datetime import datetime
-from dateutil.parser import isoparse
 
-from .const import FanModes, ActivityNames
+from .const import FanModes, ActivityTypes
 from .util import safely_get_json_value
 
-_LOGGER = logging.getLogger(__name__)
+_LOGGER = getLogger(__name__)
 
 
-def active_schedule_periods(periods_json: [dict]):
+def active_schedule_periods(periods_json: list[dict]):
     return list(filter(lambda period: safely_get_json_value(period, "enabled") == "on", periods_json))
 
 
 class ConfigZoneActivity:
     def __init__(self, zone_activity_json: dict):
-        self.api_id: ActivityNames = ActivityNames(safely_get_json_value(zone_activity_json, "$.id"))
+        self.type: ActivityTypes = ActivityTypes(safely_get_json_value(zone_activity_json, "type"))
+        self.api_id = safely_get_json_value(zone_activity_json, "id")
         self.fan: FanModes = FanModes(zone_activity_json["fan"])
         self.heat_set_point: float = safely_get_json_value(zone_activity_json, "htsp", float)
         self.cool_set_point: float = safely_get_json_value(zone_activity_json, "clsp", float)
 
     def __repr__(self):
         return {
-            "api_id": self.api_id.value,
+            "api_id": self.api_id,
+            "type": self.type.value,
             "fan": self.fan.value,
             "heat_set_point": self.heat_set_point,
             "cool_set_point": self.cool_set_point,
@@ -33,51 +34,56 @@ class ConfigZoneActivity:
 
 class ConfigZone:
     def __init__(self, zone_json: dict, vacation_json: dict):
-        self.api_id = safely_get_json_value(zone_json, "$.id")
+        self.api_id = safely_get_json_value(zone_json, "id", str)
         self.name: str = safely_get_json_value(zone_json, "name")
-        self.hold_activity: ActivityNames = safely_get_json_value(zone_json, "holdActivity", ActivityNames)
+        self.hold_activity: ActivityTypes = safely_get_json_value(zone_json, "holdActivity", ActivityTypes)
         self.hold: bool = safely_get_json_value(zone_json, "hold") == "on"
         self.hold_until: str = safely_get_json_value(zone_json, "otmr")
         self.program_json: dict = safely_get_json_value(zone_json, "program")
+        self.occupancy_enabled: bool = safely_get_json_value(zone_json, "occEnabled") == "on"
         self.activities = []
-        for zone_activity_json in safely_get_json_value(zone_json, "activities.activity"):
+        for zone_activity_json in safely_get_json_value(zone_json, "activities"):
             self.activities.append(
                 ConfigZoneActivity(zone_activity_json=zone_activity_json)
             )
         self.activities.append(ConfigZoneActivity(zone_activity_json=vacation_json))
 
-    def find_activity(self, activity_name: ActivityNames):
+    def find_activity(self, activity_name: ActivityTypes):
         for activity in self.activities:
-            if activity.api_id == activity_name:
+            if activity.type == activity_name:
                 return activity
 
+    def yesterday_active_periods(self):
+        now = datetime.now()
+        sunday_0_index_today = int(now.date().strftime("%w"))
+        yesterday_schedule = self.program_json["day"][(sunday_0_index_today + 8) % 7]
+        return active_schedule_periods(yesterday_schedule["period"])
+
+    def today_active_periods(self):
+        now = datetime.now()
+        sunday_0_index_today = int(now.date().strftime("%w"))
+        today_schedule_json = self.program_json["day"][sunday_0_index_today]
+        return active_schedule_periods(today_schedule_json["period"])
+
     def current_activity(self) -> ConfigZoneActivity:
         if self.hold:
             return self.find_activity(self.hold_activity)
         else:
             now = datetime.now()
-            sunday_0_index_today = int(now.date().strftime("%w"))
-            today_schedule_json = self.program_json["day"][sunday_0_index_today]
-            active_periods = reversed(
-                active_schedule_periods(today_schedule_json["period"])
-            )
-            for active_period in active_periods:
+            reversed_active_periods = reversed(self.today_active_periods())
+            for active_period in reversed_active_periods:
                 hours, minutes = active_period["time"].split(":")
                 if (int(hours) < now.hour) or (
                     int(hours) == now.hour and int(minutes) < now.minute
                 ):
-                    return self.find_activity(safely_get_json_value(active_period, "activity", ActivityNames))
-            yesterday_schedule = self.program_json["day"][(sunday_0_index_today + 8) % 7]
-            yesterday_active_periods = list(reversed(
-                active_schedule_periods(yesterday_schedule["period"])
-            ))
-            return self.find_activity(safely_get_json_value(yesterday_active_periods[-1], "activity", ActivityNames))
+                    return self.find_activity(safely_get_json_value(active_period, "activity", ActivityTypes))
+            yesterday_active_periods = list(self.yesterday_active_periods())
+            return self.find_activity(safely_get_json_value(yesterday_active_periods[-1], "activity", ActivityTypes))
 
-    def next_activity_time(self) -> str:
+    def next_activity_time(self) -> str | None:
         now = datetime.now()
         sunday_0_index_today = int(now.date().strftime("%w"))
-        today_schedule_json = self.program_json["day"][sunday_0_index_today]
-        active_periods = active_schedule_periods(today_schedule_json["period"])
+        active_periods = self.today_active_periods()
         for active_period in active_periods:
             hours, minutes = active_period["time"].split(":")
             if (int(hours) > now.hour) or (
@@ -85,15 +91,21 @@ class ConfigZone:
             ):
                 return active_period["time"]
         tomorrow_schedule = self.program_json["day"][(sunday_0_index_today + 1) % 7]
-        return active_schedule_periods(tomorrow_schedule["period"])[0]["time"]
+        tomorrow_active_schedule_periods = active_schedule_periods(tomorrow_schedule["period"])
+        if len(tomorrow_active_schedule_periods) > 0:
+            return tomorrow_active_schedule_periods[0]["time"]
+        else:
+            return None
 
     def __repr__(self):
         builder = {
             "api_id": self.api_id,
             "name": self.name,
+            "current_activity": self.current_activity().__repr__(),
             "hold_activity": self.hold_activity,
             "hold": self.hold,
             "hold_until": self.hold_until,
+            "occupancy_enabled": self.occupancy_enabled,
             "activities": [activity.__repr__() for activity in self.activities],
         }
         if self.hold_activity is not None:
@@ -105,41 +117,37 @@ class ConfigZone:
 
 
 class Config:
-    temperature_unit: str = None
-    static_pressure: float = None
-    mode: str = None
-    limit_min: int = None
-    limit_max: int = None
-    time_stamp: datetime = None
-    zones: [ConfigZone] = None
-    raw_config_json: dict = None
+    temperature_unit: str | None = None
+    mode: str | None = None
+    heat_source: str | None = None
+    etag: str | None = None
+    fuel_type: str | None = None
+    gas_unit: str | None = None
+    zones: list[ConfigZone] | None = None
+    uv_enabled: bool | None = None
+    humidifier_enabled: bool | None = None
 
     def __init__(
         self,
-        system,
+        raw: dict,
     ):
-        self.system = system
-        self.refresh()
-
-    def refresh(self):
-        self.raw_config_json = self.system.api_connection.get_config(
-            system_serial=self.system.serial
-        )
-        _LOGGER.debug(f"raw_config_json:{self.raw_config_json}")
-        self.temperature_unit = safely_get_json_value(self.raw_config_json, "cfgem")
-        self.static_pressure = safely_get_json_value(self.raw_config_json, "staticPressure")
-        self.mode = safely_get_json_value(self.raw_config_json, "mode")
-        self.limit_min = safely_get_json_value(self.raw_config_json, "utilityEvent.minLimit", int)
-        self.limit_max = safely_get_json_value(self.raw_config_json, "utilityEvent.maxLimit", int)
-        self.time_stamp = isoparse(safely_get_json_value(self.raw_config_json, "timestamp"))
+        self.raw = raw
+        self.temperature_unit = safely_get_json_value(self.raw, "cfgem")
+        self.mode = safely_get_json_value(self.raw, "mode")
+        self.heat_source = safely_get_json_value(self.raw, "heatsource")
+        self.etag = safely_get_json_value(self.raw, "etag")
+        self.fuel_type = safely_get_json_value(self.raw, "fueltype")
+        self.gas_unit = safely_get_json_value(self.raw, "gasunit")
+        self.uv_enabled = safely_get_json_value(self.raw, "cfguv") == "on"
+        self.humidifier_enabled = safely_get_json_value(self.raw, "cfghumid") == "on"
         vacation_json = {
-            "$": {"id": "vacation"},
-            "clsp": self.raw_config_json["vacmaxt"],
-            "htsp": self.raw_config_json["vacmint"],
-            "fan": self.raw_config_json["vacfan"],
+            "type": "vacation",
+            "clsp": self.raw["vacmaxt"],
+            "htsp": self.raw["vacmint"],
+            "fan": self.raw["vacfan"],
         }
         self.zones = []
-        for zone_json in safely_get_json_value(self.raw_config_json, "zones.zone"):
+        for zone_json in safely_get_json_value(self.raw, "zones"):
             if safely_get_json_value(zone_json, "enabled") == "on":
                 self.zones.append(
                     ConfigZone(zone_json=zone_json, vacation_json=vacation_json)
@@ -148,11 +156,8 @@ class Config:
     def __repr__(self):
         return {
             "temperature_unit": self.temperature_unit,
-            "static_pressure": self.static_pressure,
             "mode": self.mode,
-            "limit_min": self.limit_min,
-            "limit_max": self.limit_max,
-            "time_stamp": self.time_stamp.astimezone().strftime("%m/%d/%Y, %H:%M:%S %Z"),
+            "heat_source": self.heat_source,
             "zones": [zone.__repr__() for zone in self.zones],
         }
 
