@@ -1,19 +1,18 @@
-import logging
-
+from logging import getLogger
 from dateutil.parser import isoparse
-import datetime
+from datetime import datetime
 
-from .const import SystemModes, TemperatureUnits, FanModes, ActivityNames
+from .const import SystemModes, TemperatureUnits, FanModes, ActivityTypes
 from .util import safely_get_json_value
 
-_LOGGER = logging.getLogger(__name__)
+_LOGGER = getLogger(__name__)
 
 
 class StatusZone:
     def __init__(self, status_zone_json: dict):
-        self.api_id = safely_get_json_value(status_zone_json, "$.id")
+        self.api_id = safely_get_json_value(status_zone_json, "id", str)
         self.name: str = safely_get_json_value(status_zone_json, "name")
-        self.current_activity: ActivityNames = ActivityNames(status_zone_json["currentActivity"])
+        self.current_activity: ActivityTypes = ActivityTypes(status_zone_json["currentActivity"])
         self.temperature: float = safely_get_json_value(status_zone_json, "rt", float)
         self.humidity: int = safely_get_json_value(status_zone_json, "rh", int)
         self.occupancy: bool = safely_get_json_value(status_zone_json, "occupancy") == "occupied"
@@ -25,7 +24,7 @@ class StatusZone:
         self.conditioning: str = safely_get_json_value(status_zone_json, "zoneconditioning")
 
     @property
-    def zone_conditioning_const(self) -> str:
+    def zone_conditioning_const(self) -> SystemModes:
         match self.conditioning:
             case "active_heat" | "prep_heat" | "pending_heat":
                 return SystemModes.HEAT
@@ -33,6 +32,7 @@ class StatusZone:
                 return SystemModes.COOL
             case "idle":
                 return SystemModes.OFF
+        raise ValueError(f"Unknown conditioning: {self.conditioning}")
 
     def __repr__(self):
         return {
@@ -55,51 +55,55 @@ class StatusZone:
 
 
 class Status:
-    outdoor_temperature: int = None
-    mode: str = None
-    temperature_unit: str = None
-    filter_used: int = None
-    is_disconnected: bool = None
-    airflow_cfm: int = None
-    outdoor_unit_operational_status: str = None
-    indoor_unit_operational_status: str = None
-    time_stamp: datetime = None
-    zones: [StatusZone] = None
-    raw_status_json: dict = None
+    outdoor_temperature: int | None = None
+    mode: str | None = None
+    temperature_unit: TemperatureUnits | None = None
+    filter_used: int | None = None
+    is_disconnected: bool | None = None
+    airflow_cfm: int | None = None
+    blower_rpm: int | None = None
+    static_pressure: float | None = None
+    humidity_level: int | None = None
+    humidifier_on: bool | None = None
+    uv_lamp_level: int | None = None
+    outdoor_unit_operational_status: str | None = None
+    indoor_unit_operational_status: str | None = None
+    time_stamp: datetime | None = None
+    zones: list[StatusZone] | None = None
 
     def __init__(
         self,
-        system,
+        raw: dict,
     ):
-        self.system = system
-        self.refresh()
-
-    def refresh(self):
-        self.raw_status_json = self.system.api_connection.get_status(
-            system_serial=self.system.serial
-        )
-        _LOGGER.debug(f"raw_status_json:{self.raw_status_json}")
-        self.outdoor_temperature: float = safely_get_json_value(self.raw_status_json, "oat", float)
-        self.mode: str = safely_get_json_value(self.raw_status_json, "mode")
-        self.temperature_unit: TemperatureUnits = TemperatureUnits(self.raw_status_json["cfgem"])
-        self.filter_used: int = safely_get_json_value(self.raw_status_json, "filtrlvl", int)
-        self.is_disconnected: bool = safely_get_json_value(self.raw_status_json, "isDisconnected", bool)
-        self.airflow_cfm: int = safely_get_json_value(self.raw_status_json, "idu.cfm", int)
-        self.outdoor_unit_operational_status: str = safely_get_json_value(self.raw_status_json, "odu.opstat")
-        self.indoor_unit_operational_status: str = safely_get_json_value(self.raw_status_json, "idu.opstat")
-        self.time_stamp = isoparse(safely_get_json_value(self.raw_status_json, "timestamp"))
+        self.raw = raw
+        self.outdoor_temperature: float = safely_get_json_value(self.raw, "oat", float)
+        self.mode: str = safely_get_json_value(self.raw, "mode")
+        self.temperature_unit: TemperatureUnits = TemperatureUnits(self.raw["cfgem"])
+        self.filter_used: int = safely_get_json_value(self.raw, "filtrlvl", int)
+        self.humidity_level: int = safely_get_json_value(self.raw, "humlvl", int)
+        if self.raw.get('humid') is not None:
+            self.humidifier_on: bool = safely_get_json_value(self.raw, "humid", str) == 'on'
+        self.uv_lamp_level: int = safely_get_json_value(self.raw, "uvlvl", int)
+        self.is_disconnected: bool = safely_get_json_value(self.raw, "isDisconnected", bool)
+        self.airflow_cfm: int = safely_get_json_value(self.raw, "idu.cfm", int)
+        self.blower_rpm: int = safely_get_json_value(self.raw, "idu.blwrpm", int)
+        self.static_pressure: int = safely_get_json_value(self.raw, "idu.statpress", float)
+        self.outdoor_unit_operational_status: str = safely_get_json_value(self.raw, "odu.opstat")
+        self.indoor_unit_operational_status: str = safely_get_json_value(self.raw, "idu.opstat")
+        self.time_stamp = isoparse(safely_get_json_value(self.raw, "utcTime"))
         self.zones = []
-        for zone_json in self.raw_status_json["zones"]["zone"]:
+        for zone_json in self.raw["zones"]:
             if safely_get_json_value(zone_json, "enabled") == "on":
                 self.zones.append(StatusZone(zone_json))
 
     @property
-    def mode_const(self) -> str:
+    def mode_const(self) -> SystemModes:
         match self.mode:
             case "gasheat" | "electric" | "hpheat":
                 return SystemModes.HEAT
             case "dehumidify":
                 return SystemModes.COOL
+        raise ValueError(f"Unknown mode: {self.mode}")
 
     def __repr__(self):
         return {
@@ -109,9 +113,12 @@ class Status:
             "filter_used": self.filter_used,
             "is_disconnected": self.is_disconnected,
             "airflow_cfm": self.airflow_cfm,
+            "blower_rpm": self.blower_rpm,
+            "static_pressure": self.static_pressure,
+            "humidity_level": self.humidity_level,
+            "humidifier_on": self.humidifier_on,
             "outdoor_unit_operational_status": self.outdoor_unit_operational_status,
             "indoor_unit_operational_status": self.indoor_unit_operational_status,
-            "time_stamp": self.time_stamp.astimezone().strftime("%m/%d/%Y, %H:%M:%S %Z"),
             "zones": [zone.__repr__() for zone in self.zones],
         }
 
