@@ -1,6 +1,6 @@
-import logging
+from logging import getLogger
 
-_LOGGER = logging.getLogger(__name__)
+_LOGGER = getLogger(__name__)
 
 
 def safely_get_json_value(json, key, callable_to_cast=None):
@@ -15,5 +15,9 @@ def safely_get_json_value(json, key, callable_to_cast=None):
                 except (TypeError, KeyError, ValueError):
                     value = None
     if callable_to_cast is not None and value is not None:
-        value = callable_to_cast(value)
+        try:
+            value = callable_to_cast(value)
+        except ValueError as error:
+            _LOGGER.exception(error)
+            value = None
     return value
